; Simple IDL batch file to quick-check syntax errors in EDOP UF-IDL routines
; 7 April 1995
; 8 November 1995 - Added uf_acdoppler
; 3 January 1996 - Added uf_pia, uf_surfref
; 5 January 1996 - Added uf_calibration_dwell, calmode
; 13 March 1996 - Added ufday, ufmonth, ufyear
; 23 July 1996 - Added ufedop_ins_timecode, ufedop_gps_timecode
;
; datah:
;
.rnew ufcenteradj
.rnew ufdata
.rnew ufdatabits
.rnew ufdatascale
.rnew ufdataseg
.rnew ufeditcode
.rnew uffhdr_size
.rnew ufgatelength
.rnew ufgates
.rnew ufgatespace
.rnew ufhbeamwidth
.rnew ufnameddata
.rnew ufprt
.rnew ufrangezero
.rnew ufrcvrbandwidth
.rnew ufrzero
.rnew ufsamples
.rnew ufspword_size
.rnew ufspwords
.rnew ufthreshold
.rnew ufthresholdname
.rnew uftscale
.rnew uftxpol
.rnew ufvbeamwidth
.rnew ufwavelength
;
; edop:
;
.rnew uf
.rnew ufedop_dwell
.rnew ufedop_forwardazimuth
.rnew ufedop_forwardsgate
.rnew ufedop_forwardtilt
; gatezero - 11 April 95
.rnew ufedop_gatezero
.rnew ufedop_gps
.rnew ufedop_hybrid
.rnew ufedop_ins
.rnew ufedop_instrument
.rnew ufedop_latitude
.rnew ufedop_leg
.rnew ufedop_legname
.rnew ufedop_longitude
.rnew ufedop_nadirazimuth
.rnew ufedop_nadirsgate
.rnew ufedop_nadirtilt
.rnew ufedop_rtfile
.rnew ufedop_sortie
.rnew ufedop_strmodate
;
; gps:
;
.rnew ufedop_gps_altitude
.rnew ufedop_gps_ewvel
.rnew ufedop_gps_gspeed
.rnew ufedop_gps_latitude
.rnew ufedop_gps_longitude
.rnew ufedop_gps_nsvel
.rnew ufedop_gps_strtime
.rnew ufedop_gps_time
; ufedop_gps_timecode - 23 July 1996
.rnew ufedop_gps_timecode
.rnew ufedop_gps_track
.rnew ufedop_gps_vertvel
;
; hybrid:
;
.rnew ufedop_hybrid_altitude
.rnew ufedop_hybrid_ewvel
.rnew ufedop_hybrid_gspeed
.rnew ufedop_hybrid_heading
.rnew ufedop_hybrid_latitude
.rnew ufedop_hybrid_longitude
.rnew ufedop_hybrid_nsvel
.rnew ufedop_hybrid_track
.rnew ufedop_hybrid_vertvel
;
; ins:
;
.rnew ufedop_ins_altitude
.rnew ufedop_ins_drift
.rnew ufedop_ins_ewvel
.rnew ufedop_ins_gspeed
.rnew ufedop_ins_heading
.rnew ufedop_ins_latitude
.rnew ufedop_ins_longitude
.rnew ufedop_ins_nsvel
.rnew ufedop_ins_pitch
.rnew ufedop_ins_roll
.rnew ufedop_ins_strdate
.rnew ufedop_ins_strtime
.rnew ufedop_ins_time
; ufedop_ins_timecode - 23 July 1996
.rnew ufedop_ins_timecode
.rnew ufedop_ins_track
.rnew ufedop_ins_vertacc
.rnew ufedop_ins_vertvel
.rnew ufedop_ins_wind
.rnew ufedop_ins_wspeed
;
; instr:
;
.rnew ufedop_instr_bstatus
.rnew ufedop_instr_dopint
.rnew ufedop_instr_dwell
.rnew ufedop_instr_forwardbeamw
.rnew ufedop_instr_forwardtpow
.rnew ufedop_instr_freq
.rnew ufedop_instr_ifbandwidth
.rnew ufedop_instr_nadirbeamw
.rnew ufedop_instr_nadirtpow
.rnew ufedop_instr_prf
.rnew ufedop_instr_pulsew
.rnew ufedop_instr_refint
.rnew ufedop_instr_rstatus
.rnew ufedop_instr_strtime
.rnew ufedop_instr_temps
.rnew ufedop_instr_time
;
; fieldh:
;
.rnew uffieldhdr
.rnew uffieldname
.rnew uffieldname_list
.rnew uffieldnumber
.rnew uffields
.rnew ufrecfields
.rnew ufrecords
;
; manh:
;
.rnew ufazimuth
.rnew ufbaddata
.rnew ufdatahdr
.rnew ufday
.rnew ufdwell
.rnew ufelevation
.rnew uffacility
.rnew uffixedangle
.rnew ufheight
.rnew ufhours
.rnew uflatitude
.rnew uflocalhdr
.rnew uflongitude
.rnew ufminutes
.rnew ufmonth
.rnew ufoptionalhdr
.rnew ufradar
.rnew ufrecord
.rnew ufseconds
.rnew ufsite
.rnew ufstrdate
.rnew ufstrgendate
.rnew ufstrtime
.rnew ufsweep
.rnew ufsweepmode
.rnew ufsweeprate
.rnew uftime
.rnew uftimezone
.rnew ufvdwell
.rnew ufvolume
.rnew ufwords
.rnew ufyear
;
; opth:
;
.rnew ufblazimuth
.rnew ufblelevation
.rnew uffieldtape
.rnew ufgateflag
.rnew ufproject
.rnew ufstarttime
.rnew ufstrstarttime
;
; util:
; 
; uf_calibration_dwell, calmode - 5 January 96
.rnew calmode
.rnew uf_calibration_dwell
; uf_pia, uf_surfref - 3 January 96
.rnew uf_pia
.rnew uf_surfref
; uf_acdoppler - 8 November 95
.rnew uf_acdoppler
; uf_forward_sgate - 11 April 95
.rnew uf_forward_sgate
; uf_nadir_sgate - 11 April 95
.rnew uf_nadir_sgate
; uf_range_vec - 12 April 95
.rnew uf_rangevec
.rnew uf_read_dwell
.rnew uf_tostr
;
; DONE
;
print, 'DONE'
;
